# harborapi.models.buildhistory

Module that defines build history models. These are not generated from the Swagger 2.0 schema, but are instead defined manually. This is because the Swagger 2.0 schema does not define the OIDC models.

::: harborapi.models.buildhistory
    options:
        show_if_no_docstring: true
        show_source: true
        show_bases: false
